@@ -9,7 +9,7 @@ from fastapi.exception_handlers import (
 )
 from fastapi.exceptions import RequestValidationError
 from fastapi.responses import JSONResponse
-from fastapi_jwt_auth.exceptions import AuthJWTException
+from libre_fastapi_jwt.exceptions import AuthJWTException
 from kink import di
 from starlette.exceptions import HTTPException as StarletteHTTPException
 from starlette.status import HTTP_500_INTERNAL_SERVER_ERROR
@@ -58,7 +58,9 @@ async def generic_exception_handler(request: Request, exc: Exception):
     logger.error(f"Unhandled error: {str(exc)}")
     logger.debug(traceback.format_exc())
 
-    if os.getenv("ENV") == "development":
+    ENVIRONMENT: str = os.getenv('ENVIRONMENT', "Environment.PRODUCTION")
+
+    if ENVIRONMENT == "Environment.DEVELOPMENT":
         return JSONResponse(
             status_code=HTTP_500_INTERNAL_SERVER_ERROR,
             content={
